@@ -616,7 +616,11 @@ class SagemakerFeatureStore:
                         key_name = "{}:{}".format(
                             feature_group_name, str(row[record_identifier])
                         )
-                        mapping = {column: row[column] for column in row.__fields__}
+                        # convert to empty string if value is None
+                        mapping = {
+                            column: row[column] if row[column] is not None else ""
+                            for column in row.__fields__
+                        }
                         pipe.hmset(key_name, mapping)
                         pipe.expire(key_name, 259200)
 
@@ -753,6 +757,9 @@ class SagemakerFeatureStore:
                             record[key] = 1
                         else:
                             record[key] = 0
+                    # convert None to empty string
+                    elif value is None:
+                        record[key] = ""
                 pipe.hmset(key_name, record)
                 pipe.expire(key_name, 259200)
         if is_redis:
@@ -1062,6 +1069,9 @@ class SagemakerFeatureStore:
                         row[key] = 1
                     else:
                         row[key] = 0
+                # convert None to empty string
+                elif value is None:
+                    row[key] = ""
             pipe.hmset(key_name, row)
             pipe.expire(key_name, 259200)
 
